@@ -1,11 +1,11 @@
-use chrono::{DateTime, Local};
+use time::{formatting::Formattable, OffsetDateTime};
 
 /// Deferred timestamp creation.
 ///
 /// Is used to ensure that a log record that is sent to multiple outputs
 /// (in maybe different formats) always uses the same timestamp.
 #[derive(Debug)]
-pub struct DeferredNow(Option<DateTime<Local>>);
+pub struct DeferredNow(Option<OffsetDateTime>);
 impl Default for DeferredNow {
     fn default() -> Self {
         Self::new()
@@ -23,7 +23,20 @@ impl<'a> DeferredNow {
     ///
     /// Requires mutability because the first caller will generate the timestamp.
     #[allow(clippy::missing_panics_doc)]
-    pub fn now(&'a mut self) -> &'a DateTime<Local> {
-        self.0.get_or_insert_with(Local::now)
+    pub fn now(&'a mut self) -> &'a OffsetDateTime {
+        self.0.get_or_insert_with(now_local_or_utc)
+    }
+
+    /// Convert into a formatted String.
+    ///
+    /// # Panics
+    ///
+    /// if fmt has an inappropriate value
+    pub fn format(&'a mut self, fmt: &(impl Formattable + ?Sized)) -> String {
+        self.now().format(fmt).unwrap()
     }
 }
+
+pub(crate) fn now_local_or_utc() -> OffsetDateTime {
+    OffsetDateTime::now_local().unwrap_or_else(|_| OffsetDateTime::now_utc())
+}
