@@ -1,7 +1,7 @@
 use crate::FlexiLoggerError;
-use chrono::Local;
 use std::ffi::OsStr;
 use std::path::{Path, PathBuf};
+use time::{format_description, OffsetDateTime};
 
 /// Builder object for specifying the name and path of the log output file.
 ///
@@ -240,7 +240,16 @@ impl TimestampCfg {
     fn get_timestamp(&self) -> Option<String> {
         match self {
             Self::Default | Self::Yes => {
-                Some(Local::now().format("_%Y-%m-%d_%H-%M-%S").to_string())
+                Some(
+                    OffsetDateTime::now_utc()
+                    .format(
+                        &format_description::parse(
+                            "_[year]-[month]-[day]_[hour]-[minute]-[second]"
+                        )
+                        .unwrap(/*ok*/)
+                    )
+                    .unwrap(/*ok*/),
+                )
             }
             Self::No => None,
         }
@@ -251,6 +260,7 @@ impl TimestampCfg {
 mod test {
     use super::FileSpec;
     use std::path::{Path, PathBuf};
+    use time::{format_description, PrimitiveDateTime};
 
     #[test]
     fn test_default() {
@@ -289,7 +299,14 @@ mod test {
             assert_eq!(stem.as_bytes()[progname.len()], b'_');
             let s_ts = &stem[progname.len() + 1..];
             assert!(
-                chrono::naive::NaiveDateTime::parse_from_str(s_ts, "%Y-%m-%d_%H-%M-%S").is_ok(),
+                PrimitiveDateTime::parse(
+                    s_ts,
+                    &format_description::parse(
+                    "[year]-[month]-[day]_[hour]-[minute]-[second]"
+                )
+                .unwrap(/*ok*/)
+                )
+                .is_ok(),
                 "s_ts: \"{}\"",
                 s_ts
             );
