@@ -133,13 +133,14 @@ impl Drop for FileLogWriter {
 
 #[cfg(test)]
 mod test {
+    use crate::deferred_now::now_local_or_utc;
     use crate::writers::LogWriter;
     use crate::{Cleanup, Criterion, DeferredNow, FileSpec, Naming, WriteMode};
-    use chrono::Local;
-
     use std::ops::Add;
     use std::path::{Path, PathBuf};
     use std::time::Duration;
+    use time::format_description;
+
     const DIRECTORY: &str = r"log_files/rotate";
     const ONE: &str = "ONE";
     const TWO: &str = "TWO";
@@ -156,9 +157,14 @@ mod test {
     #[test]
     fn test_rotate_no_append_numbers() {
         // we use timestamp as discriminant to allow repeated runs
-        let ts = Local::now()
-            .format("false-numbers-%Y-%m-%d_%H-%M-%S")
-            .to_string();
+        let ts = now_local_or_utc()
+            .format(
+                &format_description::parse(
+                    "false-numbers-[year]-[month]-[day]_[hour]-[minute]-[second]",
+                )
+                .unwrap(),
+            )
+            .unwrap();
         let naming = Naming::Numbers;
 
         // ensure we start with -/-/-
@@ -197,9 +203,14 @@ mod test {
     #[test]
     fn test_rotate_with_append_numbers() {
         // we use timestamp as discriminant to allow repeated runs
-        let ts = Local::now()
-            .format("true-numbers-%Y-%m-%d_%H-%M-%S")
-            .to_string();
+        let ts = now_local_or_utc()
+            .format(
+                &format_description::parse(
+                    "true-numbers-[year]-[month]-[day]_[hour]-[minute]-[second]",
+                )
+                .unwrap(),
+            )
+            .unwrap();
         let naming = Naming::Numbers;
 
         // ensure we start with -/-/-
@@ -247,9 +258,14 @@ mod test {
     #[test]
     fn test_rotate_no_append_timestamps() {
         // we use timestamp as discriminant to allow repeated runs
-        let ts = Local::now()
-            .format("false-timestamps-%Y-%m-%d_%H-%M-%S")
-            .to_string();
+        let ts = now_local_or_utc()
+            .format(
+                &format_description::parse(
+                    "false-timestamps-[year]-[month]-[day]_[hour]-[minute]-[second]",
+                )
+                .unwrap(),
+            )
+            .unwrap();
 
         let basename = String::from(DIRECTORY).add("/").add(
             &Path::new(&std::env::args().next().unwrap())
@@ -283,9 +299,14 @@ mod test {
     #[test]
     fn test_rotate_with_append_timestamps() {
         // we use timestamp as discriminant to allow repeated runs
-        let ts = Local::now()
-            .format("true-timestamps-%Y-%m-%d_%H-%M-%S")
-            .to_string();
+        let ts = now_local_or_utc()
+            .format(
+                &format_description::parse(
+                    "true-timestamps-[year]-[month]-[day]_[hour]-[minute]-[second]",
+                )
+                .unwrap(),
+            )
+            .unwrap();
 
         let basename = String::from(DIRECTORY).add("/").add(
             &Path::new(&std::env::args().next().unwrap())
