@@ -1,4 +1,5 @@
-use chrono::Local;
+mod test_utils;
+
 use flexi_logger::{Logger, WriteMode};
 use log::*;
 use std::thread::{self, JoinHandle};
@@ -22,15 +23,15 @@ fn multi_threaded() {
         std::thread::sleep(std::time::Duration::from_millis(100));
         info!("********** check delay of this log line ({}) **********", i);
     }
-    let start = Local::now();
+    let start = test_utils::now_local_or_utc();
 
     let worker_handles = start_worker_threads(NO_OF_THREADS);
 
     wait_for_workers_to_close(worker_handles);
 
-    let delta = Local::now().signed_duration_since(start).num_milliseconds();
+    let delta = (test_utils::now_local_or_utc() - start).whole_milliseconds();
     debug!(
-        "Task executed with {} threads in {}ms.",
+        "Task executed with {} threads in {} ms.",
         NO_OF_THREADS, delta
     );
 }
